#! /usr/bin/python

# Copyright (c) 2015 Cumulus Networks, Inc.  All rights reserved
# Author: David Yen <dhyen@cumulusnetworks.com>

#############################################################################
# Platform and model specific eeprom subclass, inherits from the base class,
# and provides the followings:
# - the eeprom format definition
# - specific encoder/decoder if there is special need
#

try:
    import eeprom_tlvinfo
    import eeprom_base
    import struct
    import binascii
    import eeprom_ipmi_fru
except ImportError, e:
    raise ImportError (str(e) + "- required module not found")

#
# (cpu) board
#
class board(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x2000

    def __init__(self, name, path, cpld_root, ro):
        super(board, self).__init__(path, 0, "", ro, self.EEPROM_MAX_SIZE)


#
# power supply unit
#
class psu(eeprom_ipmi_fru.IpmiFruDecoder):

    def check_status(self):
        path = '/sys/class/gpio/psu_pwr' + self.name.split('psu')[1] + \
            '_present/value'
        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
                if int(status):
                    return 'ok'
                return 'absent'
        except:
            return 'absent'


#
# fans
#
class fan(eeprom_tlvinfo.TlvInfoDecoder):

    EEPROM_MAX_SIZE = 0x100
    EEPROM_OFFSET = 0x0

    def __init__(self, name, path, cpld_root, ro):
        self.name = name
        super(fan, self).__init__(path,
                                  self.EEPROM_OFFSET,
                                  "",
                                  ro,
                                  self.EEPROM_MAX_SIZE)

    def check_status(self):
        path = '/sys/class/gpio/fan' \
               + self.name.split('fan')[1] \
               + '_present/value'

        try:
            with open(path, "r") as fp:
                status = fp.readline().rstrip()
                if status == '1':
                    return 'ok'
                return 'absent'
        except:
            return 'absent'
                                                                                                                
